summaryrefslogtreecommitdiffstats
path: root/ipatests/test_ipalib/test_backend.py
diff options
context:
space:
mode:
authorRobert Kuska <rkuska@redhat.com>2015-08-24 12:40:33 +0200
committerJan Cholasta <jcholast@redhat.com>2015-09-30 10:51:36 +0200
commit01da4a8de3ed8651cc95df6125751e1603dbd14e (patch)
tree823856bad461808163b3fc05c54e0d87d26dd381 /ipatests/test_ipalib/test_backend.py
parent34e6c3ea05b23f4a5fe6fb6aaadd394967f31340 (diff)
downloadfreeipa-01da4a8de3ed8651cc95df6125751e1603dbd14e.tar.gz
freeipa-01da4a8de3ed8651cc95df6125751e1603dbd14e.tar.xz
freeipa-01da4a8de3ed8651cc95df6125751e1603dbd14e.zip
Replace StandardError with Exception
StandardError was removed in Python3 and instead Exception should be used. Signed-off-by: Robert Kuska <rkuska@redhat.com> Reviewed-By: Jan Cholasta <jcholast@redhat.com>
Diffstat (limited to 'ipatests/test_ipalib/test_backend.py')
-rw-r--r--ipatests/test_ipalib/test_backend.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/ipatests/test_ipalib/test_backend.py b/ipatests/test_ipalib/test_backend.py
index f7887bf64..4e014f654 100644
--- a/ipatests/test_ipalib/test_backend.py
+++ b/ipatests/test_ipalib/test_backend.py
@@ -90,9 +90,9 @@ class test_Connectible(ClassChecker):
assert conn.conn == 'The connection.'
assert conn.disconnect == o.disconnect
# Test that StandardError is raised if already connected:
m = "connect: 'context.%s' already exists in thread %r"
- e = raises(StandardError, o.connect, *args, **kw)
+ e = raises(Exception, o.connect, *args, **kw)
assert str(e) == m % ('example', threading.currentThread().getName())
# Double check that it works after deleting context.example:
@@ -121,7 +121,7 @@ class test_Connectible(ClassChecker):
o = example(api, shared_instance=True)
m = "disconnect: 'context.%s' does not exist in thread %r"
- e = raises(StandardError, o.disconnect)
+ e = raises(Exception, o.disconnect)
assert str(e) == m % ('example', threading.currentThread().getName())
context.example = 'The connection.'
@@ -90,9 +90,9 @@ class test_Connectible(ClassChecker):
assert conn.conn == 'The connection.'
assert conn.disconnect == o.disconnect
- # Test that StandardError is raised if already connected:
+ # Test that Exception is raised if already connected:
m = "connect: 'context.%s' already exists in thread %r"